@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_xine.c,v 1.3 2003/06/15 16:14:52 makeinu Exp $
+ * $Id: gimv_xine.c,v 1.4 2004/09/21 08:44:28 makeinu Exp $
  *
  * the xine engine in a widget - implementation
  */
@@ -479,7 +479,7 @@ load_audio_out_driver (GimvXine *this)
 
 
 #if defined (GDK_WINDOWING_X11)
-GdkFilterReturn
+static GdkFilterReturn
 filter_xine_event(GdkXEvent *xevent, GdkEvent *gdkevent, gpointer data)
 {
    XEvent *event = xevent;
@@ -513,7 +513,7 @@ filter_xine_event(GdkXEvent *xevent, GdkEvent *gdkevent, gpointer data)
 
 
 
-void
+static void
 event_listener (void *data, const xine_event_t * event)
 {
     GimvXine *gtx = GIMV_XINE (data);
@@ -786,7 +786,7 @@ gimv_xine_set_mrl (GimvXine *gtx, const gchar *mrl)
 }
 
 
-void
+static void
 visual_anim_play(GimvXine *gtx)
 {
    if(gtx->private->visual_anim.enabled == 2) {
@@ -794,7 +794,7 @@ visual_anim_play(GimvXine *gtx)
   }
 }
 
-void
+static void
 visual_anim_stop(GimvXine *gtx)
 {
    if(gtx->private->visual_anim.enabled == 2) {
@@ -899,7 +899,7 @@ gimv_xine_trick_mode (GimvXine *gtx, gint mode, gint value)
    return xine_trick_mode (priv->stream, mode, value);
 }
 
-gint
+static gint
 gimv_xine_get_pos_length (GimvXine *gtx, gint *pos_stream,
                           gint *pos_time, gint *length_time)
 {
