@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_xine_priv.c,v 1.2 2003/06/13 09:43:09 makeinu Exp $
+ * $Id: gimv_xine_priv.c,v 1.3 2004/09/21 08:44:28 makeinu Exp $
  *
  * the xine engine in a widget - implementation
  */
@@ -398,7 +398,7 @@ scale_line_15_16 (guchar *source, guchar *dest,
 }
 
 
-int
+static int
 scale_image (GimvXinePrivImage *image)
 {
    gint i;
