@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs_mplayer.c,v 1.2 2003/06/13 09:43:10 makeinu Exp $
+ * $Id: prefs_mplayer.c,v 1.3 2004/09/22 14:26:18 makeinu Exp $
  */
 
 #include "prefs_mplayer.h"
@@ -223,7 +223,7 @@ cb_ao_combo_changed (GtkEditable *editable, gpointer data)
 static GtkWidget *
 prefs_mplayer_page (void)
 {
-   GtkWidget *main_vbox, *frame, *vbox, *hbox;
+   GtkWidget *main_vbox, *frame, *vbox, *hbox, *table, *alignment;
    GtkWidget *label, *vo_combo, *ao_combo, *mplayer, *spinner, *toggle;
    GtkAdjustment *adj;
    const GList *list;
@@ -252,29 +252,47 @@ prefs_mplayer_page (void)
     **********************************************/
    gimv_prefs_ui_create_frame(_("Driver"), frame, vbox, main_vbox, FALSE);
 
+   alignment = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
+   gtk_box_pack_start (GTK_BOX (vbox), alignment, FALSE, FALSE, 0);
+   gtk_widget_show (alignment);
+
+   table = gtk_table_new (2, 2, FALSE);
+   gtk_container_add (GTK_CONTAINER (alignment), table);
+   gtk_widget_show (table);
 
    /* video driver combo */
-   hbox = gtk_hbox_new (FALSE, 0);
-   gtk_container_set_border_width(GTK_CONTAINER (hbox), 5);
-   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-   gtk_widget_show (hbox);
-
    label = gtk_label_new (_("Video driver : "));
-   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 2);
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), label);
+   gtk_table_attach (GTK_TABLE (table), alignment, 0, 1, 0, 1,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+   gtk_widget_show (alignment);
    gtk_widget_show (label);
 
    vo_combo = gtk_combo_new ();
-   gtk_box_pack_start (GTK_BOX (hbox), vo_combo, FALSE, FALSE, 2);
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), vo_combo);
+   gtk_table_attach (GTK_TABLE (table), alignment, 1, 2, 0, 1,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+   gtk_widget_show (alignment);
    gtk_widget_show (vo_combo);
    gtk_widget_set_usize (vo_combo, 100, -1);
 
    /* audio driver combo */
    label = gtk_label_new (_("Audio driver : "));
-   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 2);
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), label);
+   gtk_table_attach (GTK_TABLE (table), alignment, 0, 1, 1, 2,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+   gtk_widget_show (alignment);
    gtk_widget_show (label);
 
    ao_combo = gtk_combo_new ();
-   gtk_box_pack_start (GTK_BOX (hbox), ao_combo, FALSE, FALSE, 2);
+   alignment = gtk_alignment_new(0.0, 0.5, 0.0, 0.0);
+   gtk_container_add (GTK_CONTAINER (alignment), ao_combo);
+   gtk_table_attach (GTK_TABLE (table), alignment, 1, 2, 1, 2,
+                     GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 1);
+   gtk_widget_show (alignment);
    gtk_widget_show (ao_combo);
    gtk_widget_set_usize (ao_combo, 100, -1);
 
