@@ -18,13 +18,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: dirview2.c,v 1.31 2003/07/24 15:33:03 makeinu Exp $
+ * $Id: dirview2.c,v 1.37 2004/09/22 14:26:22 makeinu Exp $
  */
 
-#ifndef GTK_DISABLE_DEPRECATED
-#  define GTK_DISABLE_DEPRECATED
-#endif /* GTK_DISABLE_DEPRECATED */
-
 #include "dirview.h"
 
 #ifdef ENABLE_TREEVIEW
@@ -64,6 +60,9 @@ static gboolean   cb_button_press                (GtkWidget      *widget,
 static gboolean   cb_button_release              (GtkWidget      *widget,
                                                   GdkEventButton *event,
                                                   DirView        *dv);
+static gboolean   cb_scroll                      (GtkWidget      *widget,
+                                                  GdkEventScroll *se,
+                                                  DirView        *dv);
 static gboolean   cb_key_press                   (GtkWidget      *widget,
                                                   GdkEventKey    *event,
                                                   DirView        *dv);
@@ -127,6 +126,12 @@ static void       cb_drag_end                    (GtkWidget        *dirtree,
 static void       cb_toolbar_drag_begin          (GtkWidget        *widget,
                                                   GdkDragContext   *context,
                                                   gpointer          data);
+static gboolean   cb_drag_motion                 (GtkWidget *widget,
+                                                  GdkDragContext *drag_context,
+                                                  gint x,
+                                                  gint y,
+                                                  guint time,
+                                                  gpointer          data);
 static void       cb_toolbar_drag_data_get       (GtkWidget        *widget,
                                                   GdkDragContext   *context,
                                                   GtkSelectionData *seldata,
@@ -272,6 +277,57 @@ cb_button_release (GtkWidget *widget, GdkEventButton *event, DirView *dv)
 }
 
 
+static gboolean
+cb_scroll (GtkWidget *widget, GdkEventScroll *se, DirView *dv)
+{
+   GdkEventButton be;
+   gboolean retval = FALSE;
+   gint num;
+
+   g_return_val_if_fail (GTK_IS_WIDGET(widget), FALSE);
+
+   be.type       = GDK_BUTTON_PRESS;
+   be.window     = se->window;
+   be.send_event = se->send_event;
+   be.time       = se->time;
+   be.x          = se->x;
+   be.y          = se->y;
+   be.axes       = NULL;
+   be.state      = se->state;
+   be.device     = se->device;
+   be.x_root     = se->x_root;
+   be.y_root     = se->y_root;
+   switch ((se)->direction) {
+   case GDK_SCROLL_UP:
+      be.button = 4;
+      break;
+   case GDK_SCROLL_DOWN:
+      be.button = 5;
+      break;
+   case GDK_SCROLL_LEFT:
+      be.button = 6;
+      break;
+   case GDK_SCROLL_RIGHT:
+      be.button = 7;
+      break;
+   default:
+      g_warning ("invalid scroll direction!");
+      be.button = 0;
+      break;
+   }
+
+   num = prefs_mouse_get_num_from_event (&be, conf.dirview_mouse_button);
+   if (num > 0)
+      retval = dirview_button_action (dv, &be, num);
+
+   be.type = GDK_BUTTON_RELEASE;
+   if (num < 0)
+      retval = dirview_button_action (dv, &be, num);
+
+   return retval;
+}
+
+
 static gboolean
 cb_key_press (GtkWidget *widget, GdkEventKey *event, DirView *dv)
 {
@@ -320,7 +376,7 @@ cb_key_press (GtkWidget *widget, GdkEventKey *event, DirView *dv)
          if (!strcmp (label, ".") || !strcmp (label, "..")) {
             dirview_change_root (dv, path);
          } else {
-            open_dir_images (path, dv->tw,
+            open_dir_images (path, dv->tw, NULL,
                              LOAD_CACHE, conf.scan_dir_recursive);
          }
          retval = TRUE;
@@ -455,7 +511,7 @@ cb_open_thumbnail (DirView *dv, ScanSubDirType scan_subdir, GtkWidget *menuitem)
    path = dirview_get_selected_path (dv);
    if (!path) return;
 
-   open_dir_images (path, dv->tw, LOAD_CACHE, scan_subdir);
+   open_dir_images (path, dv->tw, NULL, LOAD_CACHE, scan_subdir);
 
    g_free (path);
 }
@@ -531,8 +587,9 @@ cb_mkdir (DirView *dv, guint action, GtkWidget *menuitem)
    parent_path = dirview_get_selected_path (dv);
    if (!parent_path) return;
 
-   success = make_dir_dialog (parent_path,
-                              GTK_WINDOW (dv->window));
+   success = make_dir_dialog (
+      parent_path,
+      GTK_WINDOW(gtk_widget_get_toplevel(dv->container)));
 
    if (success) {
       if (get_iter_from_path (dv, parent_path, &iter))
@@ -556,7 +613,8 @@ cb_rename_dir (DirView *dv, guint action, GtkWidget *menuitem)
    path = dirview_get_selected_path (dv);
    if (!path) return;
 
-   success = rename_dir_dialog (path, GTK_WINDOW (dv->window));
+   success = rename_dir_dialog
+      (path, GTK_WINDOW(gtk_widget_get_toplevel(dv->container)));
 
    if (success) {
       gchar *tmp_path, *parent_dir;
@@ -590,7 +648,7 @@ cb_delete_dir (DirView *dv, guint action, GtkWidget *menuitem)
    if (path [strlen (path) - 1] == '/')
       path [strlen (path) - 1] = '\0';
 
-   delete_dir (path, GTK_WINDOW (dv->window));
+   delete_dir (path, GTK_WINDOW(gtk_widget_get_toplevel(dv->container)));
    g_free (path);
 
    parent_dir = g_dirname (path);
@@ -700,6 +758,54 @@ cb_drag_data_get (GtkWidget *dirtree,
 }
 
 
+static gboolean
+cb_drag_motion (GtkWidget *widget,
+                GdkDragContext *drag_context,
+                gint x, gint y, guint time,
+                gpointer data)
+{
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	GtkTreePath *dest_path = NULL;
+	GtkTreeViewDropPosition pos;
+	gboolean success, retval = FALSE;
+   /* DirView *dv = data; */
+
+   g_return_val_if_fail(GTK_IS_TREE_VIEW(widget), FALSE);
+	g_return_val_if_fail(data, FALSE);
+
+	success = gtk_tree_view_get_dest_row_at_pos(GTK_TREE_VIEW(widget),
+                                               x, y,
+                                               &dest_path, &pos);
+	if (!success) return FALSE;
+
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(widget));
+	gtk_tree_model_get_iter(model, &iter, dest_path);
+   /*
+	gtk_tree_model_get(model, &iter,
+                      COLUMN_FULLPATH, &path,
+                      COLUMN_TERMINATOR);
+   */
+
+	if (pos == GTK_TREE_VIEW_DROP_INTO_OR_BEFORE ||
+	    pos == GTK_TREE_VIEW_DROP_INTO_OR_AFTER)
+	{
+			gdk_drag_status(drag_context, GDK_ACTION_MOVE, time);
+	}
+	else if (pos == GTK_TREE_VIEW_DROP_BEFORE ||
+            pos == GTK_TREE_VIEW_DROP_AFTER)
+	{
+			gdk_drag_status(drag_context, 0, time);
+			retval = TRUE;
+	}
+
+	if (dest_path)
+		gtk_tree_path_free(dest_path);
+
+	return retval;
+}
+
+
 static void
 cb_drag_data_received (GtkWidget *dirtree,
                        GdkDragContext *context,
@@ -748,8 +854,9 @@ cb_drag_data_received (GtkWidget *dirtree,
          g_snprintf (error_message, BUF_SIZE,
                      _("Permission denied: %s"),
                      dir_internal);
-         gtkutil_message_dialog (_("Error!!"), error_message,
-                                 GTK_WINDOW (dv->window));
+         gtkutil_message_dialog (
+            _("Error!!"), error_message,
+            GTK_WINDOW(gtk_widget_get_toplevel(dv->container)));
 
          g_free (dir_internal);
       }
@@ -983,7 +1090,8 @@ dirview_create_treeview (DirView *dv, const gchar *root)
                      G_CALLBACK (cb_button_press), dv);
    g_signal_connect (G_OBJECT (dv->dirtree),"button_release_event",
                      G_CALLBACK (cb_button_release), dv);
-   SIGNAL_CONNECT_TRANSRATE_SCROLL(dv->dirtree);
+   g_signal_connect (G_OBJECT(dv->dirtree), "scroll-event",
+                     G_CALLBACK(cb_scroll), dv);
    g_signal_connect (G_OBJECT (dv->dirtree), "key_press_event",
                      G_CALLBACK (cb_key_press), dv);
 
@@ -1003,6 +1111,8 @@ dirview_create_treeview (DirView *dv, const gchar *root)
                                          | GDK_ACTION_MOVE | GDK_ACTION_LINK);
    g_signal_connect (G_OBJECT (dv->dirtree), "drag_data_get",
                      G_CALLBACK (cb_drag_data_get), dv);
+   g_signal_connect (G_OBJECT (dv->dirtree), "drag_motion",
+                     G_CALLBACK (cb_drag_motion), dv);
    g_signal_connect (G_OBJECT (dv->dirtree), "drag_data_received",
                      G_CALLBACK (cb_drag_data_received), dv);
    g_signal_connect (G_OBJECT (dv->dirtree), "drag_end",
@@ -1029,15 +1139,9 @@ dirview_create_toolbar (DirView *dv)
    GtkWidget *toolbar;
    GtkWidget *button;
    GtkWidget *iconw;   
-   GtkWidget *container;
 
    g_return_val_if_fail (dv, NULL);
 
-   if (dv->tw)
-      container = GTK_WIDGET (dv->tw);
-   else
-      container = dv->window;
-
    toolbar = gtkutil_create_toolbar ();
 
    /* file open button */
@@ -1559,21 +1663,21 @@ idle_dirview_button_action (gpointer data)
       if (!strcmp (label, ".") || !strcmp (label, "..")) {
          dirview_change_root (dv, path);
       } else {
-         open_dir_images (path, dv->tw, LOAD_CACHE, SCAN_SUB_DIR_NONE);
+         open_dir_images (path, dv->tw, NULL, LOAD_CACHE, SCAN_SUB_DIR_NONE);
       }
       break;
    case MouseActLoadThumbRecursive:
       if (!strcmp (label, ".") || !strcmp (label, "..")) {
          dirview_change_root (dv, path);
       } else {
-         open_dir_images (path, dv->tw, LOAD_CACHE, SCAN_SUB_DIR);
+         open_dir_images (path, dv->tw, NULL, LOAD_CACHE, SCAN_SUB_DIR);
       }
       break;
    case MouseActLoadThumbRecursiveInOneTab:
       if (!strcmp (label, ".") || !strcmp (label, "..")) {
          dirview_change_root (dv, path);
       } else {
-         open_dir_images (path, dv->tw, LOAD_CACHE, SCAN_SUB_DIR_ONE_TAB);
+         open_dir_images (path, dv->tw, NULL, LOAD_CACHE, SCAN_SUB_DIR_ONE_TAB);
       }
       break;
    case MouseActChangeTop:
@@ -1928,6 +2032,8 @@ dirview_create (const gchar *root_dir,
    gtk_container_set_border_width (GTK_CONTAINER (dv->scroll_win), 1);
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (dv->scroll_win),
                                    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(dv->scroll_win),
+                                       GTK_SHADOW_IN);
    gtk_box_pack_start(GTK_BOX(dv->container), dv->scroll_win, TRUE, TRUE, 0);
    gtk_widget_show (dv->scroll_win);
 
