@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_image_win.c,v 1.10 2004/02/29 12:35:31 makeinu Exp $
+ * $Id: gimv_image_win.c,v 1.17 2004/09/29 08:53:55 makeinu Exp $
  */
 
 #include <stdlib.h>
@@ -40,6 +40,11 @@
 #include "menu.h"
 #include "prefs.h"
 
+#ifdef ENABLE_EXIF
+#   include "exif_view.h"
+#endif /* ENABLE_EXIF */
+
+
 #define IMGWIN_FULLSCREEN_HIDE_CURSOR_DELAY 1000
 
 enum {
@@ -163,6 +168,11 @@ static void     cb_fit_to_image         (GimvImageWin *iw,
 static void     cb_edit_comment         (GimvImageWin *iw,
                                          guint         action,
                                          GtkWidget    *widget);
+#ifdef ENABLE_EXIF
+static void     cb_exif                 (GimvImageWin *iw,
+                                         guint         action,
+                                         GtkWidget    *menuitem);
+#endif /* ENABLE_EXIF */
 static void     cb_create_thumb         (GimvImageWin *iw,
                                          guint         action,
                                          GtkWidget    *widget);
@@ -272,6 +282,7 @@ GtkItemFactoryEntry gimv_image_win_menu_items[] =
 
    {N_("/_Edit"),                        NULL,         NULL,              0,  "<Branch>"},
    {N_("/_Edit/Edit _Comment..."),       NULL,         cb_edit_comment,   0,  NULL},
+   {N_("/_Edit/Scan E_XIF Data..."),       NULL,       cb_exif,           0,  NULL},
    {N_("/_Edit/Create _Thumbnail"),      "<shift>T",   cb_create_thumb,   0,  NULL},
    {N_("/_Edit/---"),                    NULL,         NULL,              0,  "<Separator>"},
    {N_("/_Edit/_Options..."),            "<control>O", cb_options,        0,  NULL},
@@ -332,10 +343,10 @@ static GList         *ImageWinList   = NULL;
 static GimvImageWin  *shared_img_win = NULL;
 
 
-guint
+GtkType
 gimv_image_win_get_type (void)
 {
-   static guint gimv_image_win_type = 0;
+   static GtkType gimv_image_win_type = 0;
 
    if (!gimv_image_win_type) {
       static const GtkTypeInfo gimv_image_win_info = {
@@ -382,6 +393,8 @@ gimv_image_win_class_init (GimvImageWinClass *klass)
                         gtk_signal_default_marshaller,
                         GTK_TYPE_NONE, 0);
 
+   gtk_object_class_add_signals (object_class, gimv_image_win_signals, LAST_SIGNAL);
+
    object_class->destroy  = gimv_image_win_destroy;
 
    widget_class->realize  = gimv_image_win_realize;
@@ -476,8 +489,8 @@ gimv_image_win_init (GimvImageWin *iw)
    iw->toolbar_handle = gtk_handle_box_new();
    gtk_widget_set_name (iw->toolbar_handle, "ToolBarContainer");
    gtk_container_set_border_width (GTK_CONTAINER(iw->toolbar_handle), 2);
-   gtk_box_pack_start(GTK_BOX(vbox), iw->toolbar_handle, FALSE, FALSE, 0);
-   iw->toolbar = create_toolbar(iw, iw->toolbar_handle);
+   gtk_box_pack_start (GTK_BOX(vbox), iw->toolbar_handle, FALSE, FALSE, 0);
+   iw->toolbar = create_toolbar (iw, iw->toolbar_handle);
    gtk_container_add(GTK_CONTAINER(iw->toolbar_handle), iw->toolbar);
    gtk_widget_show_all (iw->toolbar);
 
@@ -489,13 +502,13 @@ gimv_image_win_init (GimvImageWin *iw)
       gtk_widget_show (iw->toolbar_handle);
 
    /* player toolbar */
-   iw->player_handle = gtk_handle_box_new();
+   iw->player_handle = gtk_handle_box_new ();
    gtk_widget_set_name (iw->player_handle, "PlayerToolBarContainer");
    gtk_container_set_border_width (GTK_CONTAINER(iw->player_handle), 2);
    gtk_box_pack_start(GTK_BOX(vbox), iw->player_handle, FALSE, FALSE, 0);
 
    hbox = gtk_hbox_new (FALSE, 0);
-   gtk_container_add(GTK_CONTAINER(iw->player_handle), hbox);
+   gtk_container_add (GTK_CONTAINER (iw->player_handle), hbox);
    gtk_widget_show (hbox);
 
    iw->player_bar = create_player_toolbar(iw, iw->player_handle);
@@ -571,7 +584,7 @@ gimv_image_win_init (GimvImageWin *iw)
    gtk_box_pack_start (GTK_BOX (hbox), iw->status_bar2, TRUE, TRUE, 0);
    gtk_widget_show (iw->status_bar2);
 
-   iw->progressbar = gtk_progress_bar_new();
+   iw->progressbar = gtk_progress_bar_new ();
    gtk_widget_set_name (iw->progressbar, "ProgressBar");
    gtk_box_pack_end (GTK_BOX (hbox), iw->progressbar, FALSE, FALSE, 0);
    gtk_widget_show (iw->progressbar);
@@ -660,6 +673,9 @@ gimv_image_win_realize (GtkWidget *widget)
 
    if (iw->priv->flags & GimvImageWinHideFrameFlag)
       gdk_window_set_decorations (GTK_WIDGET(iw)->window, 0);
+
+   gtk_widget_realize (iw->menubar_handle);
+
    gimv_icon_stock_set_window_icon (GTK_WIDGET(iw)->window, "gimv_icon");
 }
 
@@ -770,10 +786,10 @@ create_toolbar (GimvImageWin *iw, GtkWidget *container)
    GtkWidget *toolbar, *button, *spinner, *iconw, *menu;
    GtkAdjustment *adj;
    const gchar *rotate_labels[] = {
-      N_("-90"),
-      N_("0"),
-      N_("90"),
-      N_("180"),
+      N_("90 degrees CCW"),
+      N_("0 degrees"),
+      N_("90 degrees CW"),
+      N_("180 degrees"),
       NULL,
    };
    gfloat x_scale, y_scale;
@@ -1221,6 +1237,8 @@ cb_toggle_buffer (GimvImageWin *iw, guint action, GtkWidget *widget)
 {
    gboolean keep_buffer;
 
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
+
    if (GTK_CHECK_MENU_ITEM(widget)->active) {
       gimv_image_view_load_image_buf (iw->iv);
       keep_buffer = TRUE;
@@ -1241,6 +1259,8 @@ cb_toggle_buffer (GimvImageWin *iw, guint action, GtkWidget *widget)
 static void
 cb_window_close (GimvImageWin *iw, guint action, GtkWidget *widget)
 {
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
+
    if (iw->priv->flags & GimvImageWinCreatingFlag) return;
 
    if (iw->priv->flags & GimvImageWinFullScreenFlag) {
@@ -1255,6 +1275,8 @@ cb_window_close (GimvImageWin *iw, guint action, GtkWidget *widget)
 static void
 cb_ignore_alpha (GimvImageWin *iw, guint action, GtkWidget *widget)
 {
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
+
    gtk_object_set (GTK_OBJECT (iw->iv),
                    "ignore_alpha", GTK_CHECK_MENU_ITEM (widget)->active,
                    NULL);
@@ -1265,6 +1287,8 @@ cb_ignore_alpha (GimvImageWin *iw, guint action, GtkWidget *widget)
 static void
 cb_toggle_menubar (GimvImageWin *iw, guint action, GtkWidget *widget)
 {
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
+
    if (GTK_CHECK_MENU_ITEM(widget)->active) {
       gtk_widget_show (iw->menubar_handle);
       iw->priv->flags |= GimvImageWinShowMenuBarFlag;
@@ -1278,6 +1302,8 @@ cb_toggle_menubar (GimvImageWin *iw, guint action, GtkWidget *widget)
 static void
 cb_toggle_player (GimvImageWin *iw, guint action, GtkWidget *widget)
 {
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
+
    if (GTK_CHECK_MENU_ITEM(widget)->active) {
       gtk_widget_show (iw->player_handle);
       iw->priv->flags |= GimvImageWinShowPlayerFlag;
@@ -1291,6 +1317,8 @@ cb_toggle_player (GimvImageWin *iw, guint action, GtkWidget *widget)
 static void
 cb_toggle_toolbar (GimvImageWin *iw, guint action, GtkWidget *widget)
 {
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
+
    if (GTK_CHECK_MENU_ITEM(widget)->active) {
       gtk_widget_show (iw->toolbar_handle);
       iw->priv->flags |= GimvImageWinShowToolBarFlag;
@@ -1304,6 +1332,8 @@ cb_toggle_toolbar (GimvImageWin *iw, guint action, GtkWidget *widget)
 static void
 cb_toggle_statusbar (GimvImageWin *iw, guint action, GtkWidget *widget)
 {
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
+
    if (GTK_CHECK_MENU_ITEM(widget)->active) {
       gtk_widget_show (iw->status_bar_container);
       iw->priv->flags |= GimvImageWinShowStatusBarFlag;
@@ -1317,6 +1347,8 @@ cb_toggle_statusbar (GimvImageWin *iw, guint action, GtkWidget *widget)
 static void
 cb_toggle_scrollbar (GimvImageWin *iw, guint action, GtkWidget *widget)
 {
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
+
    if (GTK_CHECK_MENU_ITEM(widget)->active) {
       gimv_image_view_show_scrollbar (iw->iv);
    } else {
@@ -1330,7 +1362,7 @@ cb_switch_player (GimvImageWin *iw,
                   GimvImageViewPlayerVisibleType visible,
                   GtkWidget     *widget)
 {
-   g_return_if_fail (iw);
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
    g_return_if_fail (GIMV_IS_IMAGE_VIEW (iw->iv));
 
    gimv_image_view_set_player_visible (iw->iv, visible);
@@ -1345,6 +1377,8 @@ cb_toggle_maximize (GimvImageWin *iw, guint action, GtkWidget *widget)
    gint client_x, client_y, root_x, root_y;
    gint width, height;
 
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
+
    if (GTK_CHECK_MENU_ITEM(widget)->active) {
       gdk_window_get_origin (gdk_window, &root_x, &root_y);
       gdk_window_get_geometry (gdk_window, &client_x, &client_y,
@@ -1372,6 +1406,8 @@ cb_toggle_maximize (GimvImageWin *iw, guint action, GtkWidget *widget)
 static void
 cb_toggle_fullscreen (GimvImageWin *iw, guint action, GtkWidget *widget)
 {
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
+
    if (GTK_CHECK_MENU_ITEM(widget)->active) {
       gimv_image_win_fullscreen_show (iw);
    } else {
@@ -1383,6 +1419,8 @@ cb_toggle_fullscreen (GimvImageWin *iw, guint action, GtkWidget *widget)
 static void
 cb_fit_to_image (GimvImageWin *iw, guint action, GtkWidget *widget)
 {
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
+
    gimv_image_win_set_win_size (iw);
 }
 
@@ -1390,7 +1428,7 @@ cb_fit_to_image (GimvImageWin *iw, guint action, GtkWidget *widget)
 static void
 cb_edit_comment (GimvImageWin *iw, guint action, GtkWidget *menuitem)
 {
-   g_return_if_fail (iw);
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
    g_return_if_fail (iw->iv);
 
    if (iw->iv->info)
@@ -1398,12 +1436,25 @@ cb_edit_comment (GimvImageWin *iw, guint action, GtkWidget *menuitem)
 }
 
 
+#ifdef ENABLE_EXIF
+static void
+cb_exif (GimvImageWin *iw, guint action, GtkWidget *menuitem)
+{
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
+
+   if (iw->iv->info)
+      exif_view_create_window (gimv_image_info_get_path (iw->iv->info),
+                               GTK_WINDOW (iw));
+}
+#endif /* ENABLE_EXIF */
+
+
 static void
 cb_create_thumb (GimvImageWin *iw,
                  guint        action,
                  GtkWidget   *widget)
 {
-   g_return_if_fail (iw);
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
    g_return_if_fail (iw->iv);
 
    gimv_image_view_create_thumbnail (iw->iv);
@@ -1413,6 +1464,8 @@ cb_create_thumb (GimvImageWin *iw,
 static void
 cb_options (GimvImageWin *iw)
 {
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
+
    gimv_prefs_win_open_idle ("/Image Window", GTK_WINDOW (iw));
 }
 
@@ -1424,7 +1477,7 @@ cb_move_menu (GimvImageWin *iw,
 {
    gint num;
 
-   g_return_if_fail (iw);
+   g_return_if_fail (GIMV_IS_IMAGE_WIN(iw));
 
    switch (action) {
    case IMG_FIRST:
@@ -1592,9 +1645,25 @@ cb_rotate_menu (GtkWidget *widget, GimvImageWin *iw)
    gint angle;
    g_return_if_fail (GTK_IS_MENU_ITEM (widget));
    angle = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (widget), "num"));
-   angle--;
-   if (angle < 0)
+   switch (angle)
+   {
+   case 0:
+      angle = 1;
+      break;
+   case 1:
+      angle = 0;
+      break;
+   case 2:
       angle = 3;
+      break;
+   case 3:
+      angle = 2;
+      break;
+   default:
+      angle = 0;
+      break;
+   }
+
    gimv_image_view_rotate_image (iw->iv, angle);
 }
 
@@ -1875,13 +1944,13 @@ cb_rendered (GimvImageView *iv, GimvImageWin *iw)
       angle = 1;
       break;
    case GIMV_IMAGE_VIEW_ROTATE_90:
-      angle = 2;
+      angle = 0;
       break;
    case GIMV_IMAGE_VIEW_ROTATE_180:
       angle = 3;
       break;
    case GIMV_IMAGE_VIEW_ROTATE_270:
-      angle = 0;
+      angle = 2;
       break;
    default:
       break;
@@ -2378,7 +2447,7 @@ void
 gimv_image_win_change_image (GimvImageWin *iw, GimvImageInfo *info)
 {
    GList *node;
-   gboolean fit_to_frame;
+   gint default_zoom;
 
    g_return_if_fail (iw);
 
@@ -2386,10 +2455,11 @@ gimv_image_win_change_image (GimvImageWin *iw, GimvImageInfo *info)
    if (!node) return;
 
    if (conf.imgwin_raise_window
+       && GTK_WIDGET (iw)->window
        && !(iw->priv->flags & GimvImageWinFullScreenFlag))
    {
-      gdk_window_raise (GTK_WIDGET(iw)->window);
-      gdk_window_focus (GTK_WIDGET(iw)->window, GDK_CURRENT_TIME);
+      gdk_window_raise (GTK_WIDGET (iw)->window);
+      gdk_window_focus (GTK_WIDGET (iw)->window, GDK_CURRENT_TIME);
    }
 
    gimv_image_view_change_image (iw->iv, info);
@@ -2397,10 +2467,20 @@ gimv_image_win_change_image (GimvImageWin *iw, GimvImageInfo *info)
    node = g_list_find (ImageWinList, iw);
    if (!node) return;
 
+   /* If imgview_default_zoom is set to any of the "FIT" options
+    * (i.e, the image is to be fit to the window in some form), and
+    * imgwin_fit_to_image is set (i.e, the window is to be fit to the
+    * image), we have a problem - what window size to use?  If we're
+    * maximized or running in full screen mode, there's no problem,
+    * othewise use the window size in the configuration options.
+    * Not a great solution; maybe there should be a warning to
+    * the user if both options are set together.
+    */
+
    gtk_object_get (GTK_OBJECT (iw->iv),
-                   "fit_when_change", &fit_to_frame,
+                   "default_zoom", &default_zoom,
                    NULL);
-   if (fit_to_frame && conf.imgwin_fit_to_image
+   if ((default_zoom > 0) && conf.imgwin_fit_to_image
        && !(iw->priv->flags & GimvImageWinMaximizeFlag))
    {
       gdk_window_resize (GTK_WIDGET(iw)->window,
@@ -2518,10 +2598,12 @@ gimv_image_win_slideshow_play (GimvImageWin *iw)
 {
    g_return_if_fail (iw);
 
-   iw->priv->flags |= GimvImageWinSlideShowPlayingFlag;
-   iw->priv->slideshow_timer_id
-      = gtk_timeout_add (iw->priv->slideshow_interval,
-                         (GtkFunction) timeout_slideshow, iw);
+   if (iw->priv->slideshow_interval > 0) {
+      iw->priv->flags |= GimvImageWinSlideShowPlayingFlag;
+      iw->priv->slideshow_timer_id
+         = gtk_timeout_add (iw->priv->slideshow_interval,
+                            (GtkFunction) timeout_slideshow, iw);
+   }
 
    gtk_widget_set_sensitive (iw->player.play, FALSE);
    gtk_widget_set_sensitive (iw->player.stop, TRUE);
