@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gtkutils.c,v 1.26 2003/06/18 09:26:56 makeinu Exp $
+ * $Id: gtkutils.c,v 1.29 2004/09/22 14:26:23 makeinu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -196,6 +196,56 @@ gtkutil_option_menu_get_current (GtkWidget *option_menu)
 }
 
 
+GList *
+gtkutil_list_insert_sorted (GList        *list,
+                            gpointer      data,
+                            GCompareFunc  func,
+                            gboolean      reverse)
+{
+   GList *tmp_list = list;
+   GList *new_list;
+   gint cmp;
+
+   g_return_val_if_fail (func != NULL, list);
+
+   if (!list) {
+      new_list = g_list_alloc();
+      new_list->data = data;
+      return new_list;
+   }
+
+   cmp = (*func) (data, tmp_list->data);
+
+   while ((tmp_list->next) &&
+          ((!reverse && cmp > 0) || (reverse && cmp <= 0)))
+   {
+      tmp_list = tmp_list->next;
+      cmp = (*func) (data, tmp_list->data);
+   }
+
+   new_list = g_list_alloc();
+   new_list->data = data;
+
+   if ((!tmp_list->next) && (cmp > 0)) {
+      tmp_list->next = new_list;
+      new_list->prev = tmp_list;
+      return list;
+   }
+
+   if (tmp_list->prev) {
+      tmp_list->prev->next = new_list;
+      new_list->prev = tmp_list->prev;
+   }
+   new_list->next = tmp_list;
+   tmp_list->prev = new_list;
+
+   if (tmp_list == list)
+      return new_list;
+   else
+      return list;
+}
+
+
 
 /******************************************************************************
  *
@@ -531,7 +581,8 @@ gtkutil_overwrite_confirm_dialog (const gchar *title, const gchar *message,
 
       dialog.iv1 = gimv_image_view_new (NULL);
       gtk_object_set (GTK_OBJECT (dialog.iv1),
-                      "fit_when_change", TRUE,
+                      "default_zoom",     "2",
+                      "default_rotation", "0",
                       "keep_aspect",     TRUE,
                       NULL);
       gimv_image_view_hide_scrollbar (GIMV_IMAGE_VIEW (dialog.iv1));
@@ -549,7 +600,8 @@ gtkutil_overwrite_confirm_dialog (const gchar *title, const gchar *message,
 
       dialog.iv2 = gimv_image_view_new (NULL);
       gtk_object_set (GTK_OBJECT (dialog.iv2),
-                      "fit_when_change", TRUE,
+                      "default_zoom",     "2",
+                      "default_rotation", "0",
                       "keep_aspect",     TRUE,
                       NULL);
       gimv_image_view_hide_scrollbar (GIMV_IMAGE_VIEW (dialog.iv2));
@@ -1136,7 +1188,7 @@ cb_colorsel_cancel (GtkWidget *button, gboolean *retval)
 }
 
 
-void
+static void
 cb_choose_color (GtkWidget *widget, gint color[3])
 {
    GtkWidget *dialog, *button, *csel;
