@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: help.c,v 1.41 2003/07/24 15:33:03 makeinu Exp $
+ * $Id: help.c,v 1.44 2004/09/29 08:53:56 makeinu Exp $
  */
 
 #include "gimageview.h"
@@ -115,6 +115,7 @@ N_("Main Program :\n"
    "    Jin Suh\n"
    "    sheepman\n"
    "    MINAMI Hirokazu\n"
+   "    Brent Baccala\n"
    "    And all GImageView users");
 
 static gchar *system_info = NULL;
@@ -636,6 +637,10 @@ gimvhelp_create_info_widget (void)
    info_win.scrolled_win = scrolledwin;
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(scrolledwin),
                                    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#ifdef USE_GTK2
+   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolledwin),
+                                       GTK_SHADOW_IN);
+#endif /* USE_GTK2 */
    gtk_box_pack_start (GTK_BOX (vbox),
                        scrolledwin, TRUE, TRUE, 0);
    gtk_container_set_border_width (GTK_CONTAINER (scrolledwin), 5);
